@@ -19,10 +19,11 @@ from glob import glob
 from sciscripts.Analysis import Analysis
 from sciscripts.Analysis.Plot import Plot
 from sciscripts.IO import IO
+
 print('[Analysis.ABRs] Done.')
 
 ## Level 0
-def ABRPerCh(Data, Rate, TTLs, TimeWindow, FilterFreq=[600,1500], FilterOrder=4, FilterCoeff='butter', Filter='bandpass'):
+def ABRPerCh(Data, Rate, TTLs, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], FilterOrder=4, FilterCoeff='butter', Filter='bandpass'):
     """
     Extract ABR signal from each channel of Data.
 
@@ -41,12 +42,12 @@ def ABRPerCh(Data, Rate, TTLs, TimeWindow, FilterFreq=[600,1500], FilterOrder=4,
     TTLs: array_like
         Array with timestamps of each stimulus onset.
 
-    TimeWindow: array_like
-        Array containing two values, which are the beginning and ending of the
+    TimeWindow: array_like, optional
+        Array containing two time values (s), which are the beginning and ending of the
         window to be analyzed in relation to each timestamp mark.
 
     FilterFreq: array_like, optional
-        Frequency for filtering each Data channel.
+        Frequency (Hz) for filtering each Data channel.
 
     FilterOrder: int, optional
         Filter order.
@@ -66,14 +67,12 @@ def ABRPerCh(Data, Rate, TTLs, TimeWindow, FilterFreq=[600,1500], FilterOrder=4,
     ABRs = np.zeros((Len, Data.shape[1]), dtype=Data.dtype)
     ABRData = Analysis.FilterSignal(Data, Rate, FilterFreq, FilterOrder, FilterCoeff, Filter)
 
-    for Ch in range(ABRData.shape[1]):
-        ABR = Analysis.SliceData(
-            ABRData[:,Ch], TTLs,
-            -int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate),
-        )
-        ABRs[:,Ch] = ABR.mean(axis=1)
+    ABRs = Analysis.Slice(
+        ABRData, TTLs,
+        [int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate)],
+    )
+    ABRs = ABRs.mean(axis=1)
 
-    del(ABR)
     return(ABRs)
 
 
@@ -279,6 +278,8 @@ def GetThreshold(ABRs, X=[], Std=1):
     Returns
     -------
 
+    Threshold: int
+        Index of the recording that evoked the smallest detectable response.
 
     """
     Peaks = LatencyToPeaks(ABRs, X, Std=Std)
@@ -291,6 +292,9 @@ def GetThreshold(ABRs, X=[], Std=1):
 
 
 def LatencyPerFreq(Files, Freqs, Std=1):
+    """
+    Under dev
+    """
     Latencies = {}
     for F,File in enumerate(Files):
         ABRs = IO.Bin.Read(File)[0]
@@ -310,7 +314,7 @@ def LatencyPerFreq(Files, Freqs, Std=1):
     return(Latencies)
 
 
-def Single(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq=[600,1500], FilterOrder=4, Filter='bandpass', File='', ReturnX=True, Return=True):
+def Single(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], FilterOrder=4, Filter='bandpass', Save='', Return=True):
     """
     Extract ABR traces from raw data.
 
@@ -329,26 +333,24 @@ def Single(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq=[600,1500], FilterOr
     ABRCh: list
         List of channels from `Data` that contains ABR signal, *1-indexed*.
 
-    TTLCh: int
-        Channel from `Data` containing the stimulus timestamps, *1-indexed*.
+    TTLCh: list or int
+        If `int`, channel from `Data` containing the stimulus timestamps,
+        *1-indexed*. If `list`, list of stimulus timestamps (samples).
 
-    TimeWindow: list
-        List containing the start and stop time in relation to each timestamp
+    TimeWindow: list, optional
+        List containing the start and stop time (s) in relation to each timestamp
         mark. Values should be in milliseconds.
 
     FilterFreq: array_like, optional
-        Frequency for filtering each Data channel.
+        Frequency (Hz) for filtering each Data channel.
 
     FilterOrder: int, optional
         Filter order.
 
-    FilterCoeff: str, optional
-        Filter coefficient type. Can be 'butter' or 'fir'.
-
     Filter: str, optional
         Type of filtering. Can be `'lowpass'`, `'highpass'` or `'bandpass'`.
 
-    File: str, optional
+    Save: str, optional
         File for saving the array containing the processed ABR signals. If
         empty, no file will be saved.
 
@@ -368,10 +370,10 @@ def Single(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq=[600,1500], FilterOr
 
     """
 
-    X = np.arange(int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate))*1000/Rate
+    X = Analysis.GetTime(TimeWindow, Rate)*1000
 
     if type(TTLCh) == int:
-        TTLs = Analysis.QuantifyTTLsPerRec(True, Data[:,TTLCh-1])
+        TTLs = Analysis.QuantifyTTLs(Data[:,TTLCh-1])
     else:
         TTLs = TTLCh
 
@@ -381,9 +383,9 @@ def Single(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq=[600,1500], FilterOr
         print('No TTLs in this recording.')
         return(None)
 
-    if File:
-        IO.Bin.Write(X, '/'.join(File.split('/')[:-2])+'/X.dat')
-        IO.Bin.Write(ABRs, File)
+    if Save:
+        IO.Bin.Write(X, '/'.join(Save.split('/')[:-2])+'/X.dat')
+        IO.Bin.Write(ABRs, Save)
 
     if Return:
         return(ABRs, X)
@@ -393,8 +395,72 @@ def Single(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq=[600,1500], FilterOr
 
 
 ## Level 2
-def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq, Recs='all', Intensities=[], Save='', Return=True):
-    if Recs.lower() == 'all': Recs = sorted(Data.keys(), key=lambda x: int(x))
+def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], Recs=[], Intensities=[], Save='', Return=True):
+    """
+    Extract ABR traces from recordings at different intensities.
+
+    Process each data channel (see `sciscripts.Analysis.ABRs.ABRPerCh?`)
+    from each recording (see `sciscripts.Analysis.ABRs.Single?`)  according
+    to the input parameters.
+
+    Parameters
+    ----------
+    Data: dict
+        Dictionary containing one array per key, where each array is a two-
+        dimensional array ([samples, channels]) containing neural data and
+        a channel containing stimulus timestamp marks; each recorded under
+        stimulation at a particular intensity (dict key). If `Recs` is not
+        provided, the keys will be sorted. Each array should have two
+        dimensions ([samples, channels]), even if channels==1.
+
+    Rate: int
+        Sampling rate in which `Data` was acquired.
+
+    ABRCh: list
+        List of channels from `Data` that contains ABR signal, *1-indexed*. If
+        `ABRCh` is a list of lists, then each list will be used to each
+        recording under `Data`, ordered as in `Recs`.
+
+    TTLCh: list or int
+        If `int`, channel from `Data` containing the stimulus timestamps,
+        *1-indexed*. If `list`, list of stimulus timestamps (samples).
+
+    TimeWindow: list, optional
+        List containing the start and stop time (s) in relation to each timestamp
+        mark. Values should be in milliseconds.
+
+    FilterFreq: array_like, optional
+        Frequency (Hz) for filtering each Data channel.
+
+    Recs: list, optional
+        List containing which keys in `Data` to be processed. Recordings will
+        be processed in the order they are provided. If empty, keys in `Data`
+        will be sorted and all recordings will be processed.
+
+    Intensities: list, optional
+        List containing the stimuli intensities used for each recording under
+        `Data`. Should be provided in the same order as `Recs`. If empty, it
+        will be the sorted `Data` keys as integers.
+
+    Save: str, optional
+        Path for saving the arrays containing the processed ABR signals. If
+        empty, no file will be saved.
+
+    Return: bool, optional
+        Toggle for disabling the return of the resulting ABR dict. Useful for
+        when running several datasets and writing the results to files..
+
+    Returns
+    -------
+    ABRs: dict
+        Dict containing arrays ([samples, channels]) containing the processed
+        ABR signals for each channel in each key of `Data`.
+
+    X: array
+        Array with time values based on `TimeWindow`.
+
+    """
+    if not len(Recs): Recs = sorted(Data.keys(), key=lambda x: int(x))
 
     ABRs = {}
     for R,Rec in enumerate(Recs):
@@ -416,7 +482,7 @@ def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq, Recs='all', Inten
             File=Save_R, Return=Return
         )[0]
 
-    X = np.arange(int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate))*1000/Rate
+    X = Analysis.GetTime(TimeWindow, Rate)*1000
 
     if Save:
         IO.Bin.Write(X, '/'.join(Save.split('/')[:-1])+'/X.dat')
@@ -430,6 +496,9 @@ def Multiple(Data, Rate, ABRCh, TTLCh, TimeWindow, FilterFreq, Recs='all', Inten
 
 ## Level 3
 def GetThresholdsPerFreq(Folders, Std=1):
+    """
+    Under dev
+    """
     Thresholds = {'Thresholds': [], 'Freqs':[]}
 
     for Folder in Folders:
@@ -448,6 +517,9 @@ def GetThresholdsPerFreq(Folders, Std=1):
     return(Thresholds)
 
 def GetWaveAmpPerFreq(Folders, Std=1):
+    """
+    Under dev
+    """
     WaveAmps = {'Amps': [], 'Freqs':[]}
 
     for Folder in Folders:
@@ -478,316 +550,112 @@ def GetWaveAmpPerFreq(Folders, Std=1):
     return(WaveAmps)
 
 
-def Session(Folders, Freqs, Intensities, ABRCh, TTLCh, TimeWindow, FilterFreq, Proc='100', ChannelMap=None, AnalysisFolder=''):
+def Session(Folders, Freqs, ABRCh, TTLCh, TimeWindow=[-0.003,0.012], FilterFreq=[600,1500], Intensities=[], Proc='', ChannelMap=[], Save='', Return=True):
+    """
+    Extract ABR traces from recordings at different frequencies and intensities.
+
+    Process each data channel (see `sciscripts.Analysis.ABRs.ABRPerCh?`)
+    from each recording (see `sciscripts.Analysis.ABRs.Single?`) from each
+    folder (see `sciscripts.Analysis.ABRs.Multiple?`) according to the input
+    parameters.
+
+    Parameters
+    ----------
+    Folders: list
+        List containing paths for neural recordings. Those folders must be
+        loadable by `sciscripts.IO.IO.DataLoader`.
+
+    Freqs: list
+        List of stimulation frequencies (`str`) used for each folder in `Folders`.
+
+    ABRCh: list
+        List of channels from `Data` that contains ABR signal, *1-indexed*. If
+        `ABRCh` is a list of lists, then each list will be used to each folder
+        under `Folders`, respectively.
+
+    TTLCh: list or int
+        List of channels from `Data` containing the stimulus timestamps,
+        *1-indexed*, for each folder. If `int`, then the same channel will be
+        used for all folders.
+
+    TimeWindow: list, optional
+        List containing the start and stop time (s) in relation to each timestamp
+        mark. Values should be in milliseconds.
+
+    FilterFreq: array_like, optional
+        Frequency (Hz) for filtering each Data channel.
+
+    Intensities: list, optional
+        List containing the stimuli intensities used for each recording under
+        `Data`. Should be provided in the same order as `Recs`. If empty, it
+        will be the sorted `Data` keys as integers.
+
+    Proc: str
+        If the folders contain data recorded from more than one processor,
+        only data from `Proc` will be processed. If empty, all processors will
+        be sorted and the first will be selected.
+
+    ChannelMap: list, optional
+        Ordering of channels. Must have the same number of channels as in the
+        recorded data under `Folders`.
+
+    Save: str, optional
+        Path for saving the arrays containing the processed ABR signals. If
+        empty, no file will be saved. If `'auto'`, files will be saved at
+        `$ANALYSISPATH`.
+
+    Return: bool, optional
+        Toggle for disabling the return of the resulting ABR dict. Useful for
+        when running several datasets and writing the results to files..
+
+    Returns
+    -------
+    ABRs: dict
+        Dict
+            containing dicts
+                containing arrays ([samples, channels])
+                    containing the processed ABR signals
+                    for each channel
+                for each key of `Data`
+            for each folder in `Folders`
+        .
+
+    X: array
+        Array with time values based on `TimeWindow`.
+
+    """
+    ABRs = {}
     for F, Folder in enumerate(Folders):
         print(Folder.replace(os.environ['DATAPATH']+'/', '').replace(os.environ['HOME']+'/', ''))
         Data, Rate = IO.DataLoader(Folder, Unit='uV', ChannelMap=ChannelMap)
-        if len(Data.keys()) == 1: Proc = list(Data.keys())[0]
-        else: ChNo, Proc = IO.OpenEphys.GetChNoAndProcs(Folder+'/settings.xml')
+
+        if not len(Proc):
+            if len(Data.keys()) == 1: Proc = list(Data.keys())[0]
+            else: ChNo, Proc = IO.OpenEphys.GetChNoAndProcs(Folder+'/settings.xml')
 
         Data, Rate = Data[Proc]['0'], Rate[Proc]['0']
-        print('')
-        print([_.shape for _ in Data.values()])
-
-        if not AnalysisFolder:
-            AnalysisFolder = os.environ['ANALYSISPATH'] + '/' + Folder.split('/')[-3]
-
-        XSavePath = '/'.join([AnalysisFolder, Folder.split('/')[-2], 'ABRs', Freqs[F]])
-        if os.path.isdir(XSavePath): Trial = 'Trial'+str(len(glob(XSavePath)))
-        else: Trial = 'Trial0'
-        SavePath = '/'.join([XSavePath, Trial])
-
         TTLCh_F = TTLCh[F] if type(TTLCh) == list else TTLCh
         ABRCh_F = ABRCh[F] if type(ABRCh[0]) == list else ABRCh
 
-        Multiple(Data, Rate, ABRCh_F, TTLCh_F, TimeWindow, FilterFreq, Recs='all', Intensities=Intensities, Save=SavePath, Return=False)
+        if len(Save):
+            if Save.lower() == 'auto':
+                Save = os.environ['ANALYSISPATH'] + '/' + Folder.split('/')[-3]
+
+            XSavePath = '/'.join([Save, Folder.split('/')[-2], 'ABRs', Freqs[F]])
+            if os.path.isdir(XSavePath): Trial = 'Trial'+str(len(glob(XSavePath)))
+            else: Trial = 'Trial0'
+            SavePath = '/'.join([XSavePath, Trial])
+        else:
+            SavePath = ''
+
+        ABRs[Freqs[F]], X = Multiple(Data, Rate, ABRCh_F, TTLCh_F, TimeWindow, FilterFreq, Recs='all', Intensities=Intensities, Save=SavePath, Return=Return)
 
         del(Data)
 
-
-## Helper functions
-def WriteRecAndTTLCh(Folders):
-    for Folder in Folders:
-        print(Folder)
-        Data, Rate = IO.DataLoader(Folder, Unit='uV', ChannelMap=[])
-        if len(Data.keys()) == 1: Proc = list(Data.keys())[0]
-        Data, Rate = Data[Proc]['0'], Rate[Proc]['0']
-
-        InfoFile = glob(Folder+'/../*.dict')[0]
-
-        for R, Rec in Data.items():
-            print(R)
-            Info = IO.Txt.Read(InfoFile)
-            TTLs = []
-            if Info['DAqs']['TTLCh'] <= Rec.shape[1]:
-                TTLs = Analysis.QuantifyTTLsPerRec(True, Rec[:,Info['DAqs']['TTLCh']-1])
-
-            if len(TTLs) < 100 or len(TTLs) > Info['Audio']['SoundPulseNo']+100:
-                print('TTLs:', len(TTLs))
-                while len(TTLs) < 100 or len(TTLs) > Info['Audio']['SoundPulseNo']+100:
-                    Break = ''
-                    Chs = [Rec[:int(Rate/2),Ch] for Ch in range(Rec.shape[1])]
-                    Plot.RawCh(Chs, Lines=len(Chs), Cols=1, Save=False)
-
-                    TTLCh = input('TTLCh: ')
-                    RecCh = input('RecCh (space separated): ')
-                    TTLCh = int(TTLCh)
-                    RecCh = [int(_) for _ in RecCh.split(' ')]
-                    Break = input('Break [y/N]? ')
-
-                    if Break.lower() in ['y', 'yes']: break
-                    TTLs = Analysis.QuantifyTTLsPerRec(True, Rec[:,TTLCh-1])
-                print('TTLs:', len(TTLs))
-
-                if Break.lower() not in ['y', 'yes']:
-                    if RecCh != Info['DAqs']['RecCh']:
-                        Info['DAqs']['RecCh'] = RecCh
-                        IO.Txt.Write(Info, InfoFile)
-                        IO.Bin.Write(Rec[:,RecCh], Folder+'/RecCh_'+R+'.dat')
-
-
-                    Info['DAqs']['TTLCh'] = TTLCh
-                    IO.Txt.Write(Info, InfoFile)
-                    IO.Bin.Write(TTLs, Folder+'/TTLs_'+R+'.dat')
-
-    return(None)
-
-
-NoTTLsFile = os.environ['ANALYSISPATH']+'/Experiments/NoTTLRecs.dict'
-
-def _PrintOptions():
-    print('')
-    print('This plot shows the first 0.5s of this recording.')
-    print('What to do?')
-    print('1) Decrease TTL Threshold')
-    print('2) Change TTL channel')
-    print('3) Decrease TTL Threshold and change TTL channel')
-    print('4) Choose a startpoint for TTLs')
-    print('5) Plot TTLCh and TTL threshold')
-    print('6) Change ABR and TTL channels')
-    print('7) Ignore PulseNo restritions')
-    print('8) Report broken rec')
-    print('9) Abort')
-    print('')
-
-    return(None)
-
-
-def FixTTLs(Data, Rate, DataInfo, Freq, Rec, AnalogTTLs):
-    NoTTLRecs = IO.Txt.Read(NoTTLsFile)
-    F = DataInfo['InfoFile'].split('/')[-1].split('.')[0]
-    TTLCh = DataInfo['DAqs']['TTLCh']
-    DataCh = DataInfo['DAqs']['RecCh']
-
-
-    WhatToDo = None; IgnoreRestritions = False
-    if F in NoTTLRecs:
-        if Freq in NoTTLRecs[F]:
-            if Rec in NoTTLRecs[F][Freq]:
-                WhatToDo = NoTTLRecs[F][Freq][Rec]['WhatToDo']
-                Std = NoTTLRecs[F][Freq][Rec]['Std']
-                SampleStart = NoTTLRecs[F][Freq][Rec]['SampleStart']
-
-                if NoTTLRecs[F][Freq][Rec]['TTLCh']:
-                    TTLCh = NoTTLRecs[F][Freq][Rec]['TTLCh']
-
-                if NoTTLRecs[F][Freq][Rec]['DataCh']:
-                    DataCh = NoTTLRecs[F][Freq][Rec]['DataCh']
-
-                if WhatToDo == '6': ChangedDataCh = True
-
-
-    NoChoice = False
-    if not WhatToDo:
-        NoChoice = True
-        if 'Plot' not in locals():
-            from Analysis.Plot import Plot
-            plt = Plot.Return('plt')
-
-        print('DataCh:', DataCh)
-        print('TTLCh:', TTLCh)
-        print('')
-        _PrintOptions()
-
-        Chs = Data[:int(Rate/2),:]
-
-        if DataInfo['InfoFile'].split('/')[-1].split('-')[0] in ['20170623145925', '20170623162416']:
-            Chs[:,-1] = Analysis.FilterSignal(Chs[:,-1], Rate, [8000, 14900])
-
-        Fig, Axes = plt.subplots(1,2,figsize=(10,5), sharex=True)
-        Axes[0] = Plot.AllCh(Chs, lw=0.6, Ax=Axes[0])
-        Axes[1].plot(Analysis.GetInstFreq(Data[:int(Rate/2),TTLCh-1], Rate))
-        plt.show()
-
-        WhatToDo = input(': ')
-
-        if F not in NoTTLRecs: NoTTLRecs[F] = {}
-        if Freq not in NoTTLRecs[F]: NoTTLRecs[F][Freq] = {}
-        if Rec not in NoTTLRecs[F][Freq]: NoTTLRecs[F][Freq][Rec] = {}
-
-        NoTTLRecs[F][Freq][Rec]['WhatToDo'] = WhatToDo
-        for K in ['SampleStart', 'Std', 'TTLCh', 'DataCh']:
-            if K not in NoTTLRecs[F][Freq][Rec].keys():
-                NoTTLRecs[F][Freq][Rec][K] = None
-
-        Std = NoTTLRecs[F][Freq][Rec]['Std']
-        SampleStart = NoTTLRecs[F][Freq][Rec]['SampleStart']
-        ChangedDataCh = False
-
-
-    if WhatToDo == '1':
-        if not Std or NoChoice:
-            Std = input('How many std above the mean should the threshold be? ')
-            Std = float(Std)
-
-        TTLs = Analysis.QuantifyTTLsPerRec(AnalogTTLs, Data[:,TTLCh-1], Std)
-
-        NoTTLRecs[F][Freq][Rec]['Std'] = Std
-        IO.Txt.Write(NoTTLRecs, NoTTLsFile)
-
-    elif WhatToDo == '2':
-        if not TTLCh or NoChoice:
-            TTLCh = input('TTL channel: '); TTLCh = int(TTLCh)
-
-        TTLs = Analysis.QuantifyTTLsPerRec(AnalogTTLs, Data[:,TTLCh-1])
-
-        NoTTLRecs[F][Freq][Rec]['TTLCh'] = TTLCh
-
-    elif WhatToDo == '3':
-        if not Std or NoChoice:
-            Std = input('How many std above the mean should the threshold be? ')
-            Std = float(Std)
-
-        if not TTLCh:
-            TTLCh = input('TTL channel: '); TTLCh = int(TTLCh)
-            TTLs = Analysis.QuantifyTTLsPerRec(AnalogTTLs, Data[:,TTLCh-1], Std)
-
-        NoTTLRecs[F][Freq][Rec]['Std'] = Std
-        NoTTLRecs[F][Freq][Rec]['TTLCh'] = TTLCh
-        IO.Txt.Write(NoTTLRecs, NoTTLsFile)
-
-    elif WhatToDo == '4':
-        if not SampleStart:
-            SampleStart = input('Sample of the rising edge of the 1st pulse: ')
-            SampleStart = int(SampleStart)
-
-        TTLs = Analysis.GenFakeTTLsRising(Rate, DataInfo['Audio']['SoundPulseDur'],
-                                  DataInfo['Audio']['SoundPauseBeforePulseDur'],
-                                  DataInfo['Audio']['SoundPauseAfterPulseDur'], SampleStart,
-                                  DataInfo['Audio']['SoundPulseNo'])
-
-        NoTTLRecs[F][Freq][Rec]['SampleStart'] = SampleStart
-
-    elif WhatToDo == '5':
-        Std = NoTTLRecs[F][Freq][Rec]['Std']
-
-        Threshold = Analysis.GetTTLThreshold(Data[:,TTLCh-1], Std)
-        Plot.TTLCh(Data[:,TTLCh-1], Std, Threshold)
-        TTLs = []
-
-    elif WhatToDo == '6':
-        if not ChangedDataCh:
-            NewABRCh = input('ABR channels (comma separated): ')
-            NewABRCh = [int(_) for _ in NewABRCh.split(',')]
-            TTLCh = input('TTL channel: '); TTLCh = int(TTLCh)
-
-            TTLs = Analysis.QuantifyTTLsPerRec(AnalogTTLs, Data[:,TTLCh-1])
-
-            NoTTLRecs[F][Freq][Rec]['DataCh'] = NewABRCh
-            NoTTLRecs[F][Freq][Rec]['TTLCh'] = TTLCh
-
-            Info = {'ABRCh': NewABRCh, 'TTLCh': TTLCh}
-            print(len(TTLs), 'TTLs')
-            print('ABR Channels changed. Restarting calculations...')
-            print('')
-        else:
-            TTLs = Analysis.QuantifyTTLsPerRec(AnalogTTLs, Data[:,TTLCh-1])
-
-    elif WhatToDo == '7':
-        Std = NoTTLRecs[F][Freq][Rec]['Std']
-
-        TTLs = Analysis.QuantifyTTLsPerRec(AnalogTTLs, Data[:,TTLCh-1], Std)
-        IgnoreRestritions = True
-
-    elif WhatToDo == '8':
-        TTLs = []
-        NoTTLRecs[F][Freq][Rec]['BrokenRec'] = True
-        IO.Txt.Write(NoTTLRecs, NoTTLsFile)
-        return('Broken')
-
+    if Return:
+        return(ABRs, X)
     else:
-        print('Aborted.')
-        raise(SystemExit)
-
-
-    if not IgnoreRestritions:
-        if len(TTLs) > DataInfo['Audio']['SoundPulseNo']+4 or len(TTLs) < 100:
-            TTLs = []
-
-    if len(TTLs) == 0:
-        NoTTLRecs[F][Freq][Rec]['WhatToDo'] = None
-        IO.Txt.Write(NoTTLRecs, NoTTLsFile)
-    else:
-        IO.Txt.Write(NoTTLRecs, NoTTLsFile)
-        if WhatToDo == '6'and not ChangedDataCh: return(Info)
-
-    print(len(TTLs), 'TTLs after fix.')
-    return(TTLs)
-
-
-def GetTTLs(Data, Rate, DataInfo, DataFolder, AnalogTTLs=True, R=None, Freq=None):
-    TTLCh = DataInfo['DAqs']['TTLCh']
-    ABRCh = DataInfo['DAqs']['RecCh']
-
-    if TTLCh > Data.shape[1]:
-        print('TTLCh > ChNo; replaced by -1.')
-        TTLCh = 0
-
-    print('TTL mean and max:', np.mean(Data[:,TTLCh-1]), np.max(Data[:,TTLCh-1]))
-    TTLs = Analysis.QuantifyTTLsPerRec(AnalogTTLs, Data[:,TTLCh-1])
-    if len(TTLs) > DataInfo['Audio']['SoundPulseNo']+10 or len(TTLs) < 100:
-        TTLs = []
-
-    if max(ABRCh) > Data.shape[1]:
-        print(''); print('Wrong ABR Channels!'); print('')
-
-    TTLFile = glob(DataFolder+'/Rec_'+R+'_TTLs.TTLs')
-    if len(TTLFile):
-        TTLs = IO.Bin.Read(TTLFile[0])[0]
-
-        if TTLs[0] == 'Broken':
-            print('Exp', DataFolder.split('/')[-1], 'Rec', R, 'is broken.')
-            return('Broken')
-
-    if not len(TTLs):
-        print('Fixing TTLs...')
-        while len(TTLs) == 0:
-            TTLs = FixTTLs(Data, Rate, DataInfo, Freq, R, AnalogTTLs)
-
-        if type(TTLs) == dict:
-            DI = deepcopy(DataInfo)
-            DI['DAqs']['RecCh'] = TTLs['ABRCh']
-            DI['DAqs']['TTLCh'] = TTLs['TTLCh']
-
-            TTLs = []
-            while len(TTLs) == 0:
-                TTLs = FixTTLs(Data, Rate, DI, Freq, R, AnalogTTLs)
-
-            Chs = [_-1 for _ in DI['DAqs']['RecCh']]
-
-            IO.Bin.Write(Data[:,Chs], DataFolder+'/Rec_'+R+'_ABRs.ABRs')
-
-        if type(TTLs) == str:
-            if TTLs == 'Broken':
-                print('Exp', DataFolder.split('/')[-1], 'Rec', R, 'is broken.')
-                IO.Bin.Write(np.array(['Broken']), DataFolder+'/Rec_'+R+'_TTLs.TTLs')
-                return(TTLs)
-
-        if type(TTLs) == list: TTLs = np.array(TTLs)
-        IO.Bin.Write(TTLs, DataFolder+'/Rec_'+R+'_TTLs.TTLs')
-        print('Done')
-
-    print(len(TTLs), 'TTLs')
-    return(TTLs)
+        del(ABRs, X)
+        return(None)
 
 
