@@ -204,10 +204,11 @@ def GetMAFIndexes(Indexes_IFAE, MAF, Animals, ExpOrder):
     return(Indexes)
 
 
-def IndexCalc(Data, Keys, PulseSampleStart, SliceSize, BGNormalize=True):
+def IndexCalc(Data, X, SliceSamples, Keys, BGNormalize=True):
     Index = {}
     for Key in Keys:
-        PulseStart = PulseSampleStart; PulseEnd = PulseSampleStart + SliceSize
+        PulseStart = np.where((X >= 0))[0][0]
+        PulseEnd = PulseStart + SliceSamples
 
         if type(Data[Key[0]]) == list:
             if not Data[Key[0]]:
@@ -218,7 +219,8 @@ def IndexCalc(Data, Keys, PulseSampleStart, SliceSize, BGNormalize=True):
         RefRMSPulse = (np.mean(Data[Key[1]][PulseStart:PulseEnd]**2))**0.5
 
         if BGNormalize:
-            BGStart = PulseSampleStart-SliceSize; BGEnd = PulseSampleStart
+            BGStart = PulseStart-SliceSamples
+            BGEnd = PulseStart
             ResRMSBG = (np.mean(Data[Key[0]][BGStart:BGEnd]**2))**0.5
             RefRMSBG = (np.mean(Data[Key[1]][BGStart:BGEnd]**2))**0.5
 
@@ -247,7 +249,7 @@ def PreallocateDict(Freqs):
     return(Dict)
 
 
-def OrganizeRecs(Dict, Data, Rate, DataInfo, AnalogTTLs, TimeWindow, Proc=None, Events=None,
+def OrganizeRecs(Dict, Data, Rate, DataInfo, TimeWindow,
                  FilterFreq=[70, 400], FilterOrder=4, FilterType='', Filter='butter'):
 
     Recs = sorted(Data.keys(), key=lambda i: int(i))
@@ -265,19 +267,19 @@ def OrganizeRecs(Dict, Data, Rate, DataInfo, AnalogTTLs, TimeWindow, Proc=None,
         elif Trial % 2 == 0: STrial = 'NoGap'
         else: STrial = 'Gap'
 
-        if AnalogTTLs:
-            TTLs = sAnalysis.QuantifyTTLsPerRec(AnalogTTLs, Rec[:,DataInfo['DAqs']['TTLCh']-1])
-            if len(TTLs) > 1:
-                print('More than one TTL detected!!')
-                # TTLs = [Rec[:,DataInfo['DAqs']['TTLCh']-1].argmax()]    # Get larger TTL
-                TTLs = [TTLs[0]]                                          # Get first TTL
-            # print(TTLs)
+        if STrial in ['Pre', 'Post']:
+            print('Pre- and Post- trials still to be implemented. Skipping...')
+            continue
 
-            if not TTLs: print('No TTL detected. Skipping trial...'); continue
+        TTLs = sAnalysis.QuantifyTTLs(Rec[:,DataInfo['DAqs']['TTLCh']-1])
+        if len(TTLs) > 1:
+            print('More than one TTL detected!!')
+            # TTLs = [Rec[:,DataInfo['DAqs']['TTLCh']-1].argmax()]    # Get larger TTL
+            TTLs = [TTLs[0]]                                          # Get first TTL
+        # print(TTLs)
+
+        if not TTLs: print('No TTL detected. Skipping trial...'); continue
 
-        else:
-            TTLs = sAnalysis.QuantifyTTLsPerRec(AnalogTTLs, EventsDict=Events,
-                                      TTLCh=DataInfo['DAqs']['TTLCh'], Proc=Proc, Rec=R)
 
         if not FilterType:
             if len(FilterFreq) == 1: FilterType = 'lowpass'
@@ -286,11 +288,6 @@ def OrganizeRecs(Dict, Data, Rate, DataInfo, AnalogTTLs, TimeWindow, Proc=None,
         if len(DataInfo['DAqs']['RecCh']) == 1:
             GD = sAnalysis.FilterSignal(Rec[:,DataInfo['DAqs']['RecCh'][0]-1],
                                            Rate, FilterFreq, FilterOrder, Filter, FilterType)
-            # GD = Rec[:,DataInfo['DAqs']['RecCh'][0]-1]
-
-            GD -= GD.mean()
-            GD = sAnalysis.SliceData(GD, TTLs, -int(TimeWindow[0]*Rate),
-                                     int(TimeWindow[1]*Rate), AnalogTTLs)
 
         elif len(DataInfo['DAqs']['RecCh']) == 3:
             X = sAnalysis.FilterSignal(Rec[:,DataInfo['DAqs']['RecCh'][0]-1],
@@ -305,11 +302,8 @@ def OrganizeRecs(Dict, Data, Rate, DataInfo, AnalogTTLs, TimeWindow, Proc=None,
                 np.abs(Y-Y.mean()),
                 np.abs(Z-Z.mean())], axis=0)
 
-            GD -= GD.mean()
-
-            GD = sAnalysis.SliceData(
-                GD, TTLs, -int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate),
-            )
+        GD -= GD.mean()
+        GD = sAnalysis.Slice(GD, TTLs, [int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate)])
 
         Dict['IndexTrace'][SFreq][STrial].append(GD)
         Dict['Trace'][SFreq][STrial].append(GD)
@@ -320,7 +314,7 @@ def OrganizeRecs(Dict, Data, Rate, DataInfo, AnalogTTLs, TimeWindow, Proc=None,
 ## Level 1
 def GetAllTrials(
         Data, DataInfo, Rate, TimeWindow=[-0.1, 0.15], FilterFreq=[70, 400],
-        FilterOrder=3, FilterType='', Filter='butter', AnalogTTLs=True
+        FilterOrder=3, FilterType='', Filter='butter'
     ):
 
     if not DataInfo:
@@ -340,8 +334,10 @@ def GetAllTrials(
                             GD = Trial.copy()
 
                         GD -= GD.mean()
-                        GD = sAnalysis.SliceData(GD, GPIASData['TTLs'], -int(TimeWindow[0]*Rate),
-                                                 int(TimeWindow[1]*Rate), AnalogTTLs)
+                        GD = sAnalysis.Slice(
+                            GD, GPIASData['TTLs'],
+                            [int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate)]
+                        )
 
                         print(Key, F, G, T)
                         GPIASData[Key][F][G][T] = GD.copy()
@@ -350,26 +346,27 @@ def GetAllTrials(
 
     else:
         GPIASData = PreallocateDict(DataInfo['Audio']['NoiseFrequency'])
-        GPIASData = OrganizeRecs(GPIASData, Data, Rate, DataInfo, AnalogTTLs,
-                                       TimeWindow, None, None,
+        GPIASData = OrganizeRecs(GPIASData, Data, Rate, DataInfo,
+                                       TimeWindow,
                                        FilterFreq, FilterOrder, FilterType, Filter)
 
     return(GPIASData)
 
 
 ## Level 2
-def Analysis(Data, DataInfo, Rate, AnalysisFolder, AnalysisKey,
-             TimeWindow=[-0.1, 0.15],
-             FilterFreq=[70, 400], FilterOrder=3, FilterType='', Filter='butter',
-             SliceSize=100, AnalogTTLs=True, Return=False, Save=True):
+def Analysis(
+        Data, Rate, DataInfo,
+        TimeWindow=[-0.15, 0.15], SliceSize=0.1,
+        FilterFreq=[70, 400], FilterOrder=3, FilterType='', Filter='butter',
+        BGNormalize=True, Save='', Return=True):
+
+    X = sAnalysis.GetTime(TimeWindow, Rate)*1000
 
     GPIASData = GetAllTrials(
         Data, DataInfo, Rate, TimeWindow, FilterFreq,
-        FilterOrder, FilterType, Filter, AnalogTTLs
+        FilterOrder, FilterType, Filter,
     )
 
-    SliceSize = int(SliceSize * (Rate/1000))
-
     for Freq in GPIASData['IndexTrace'].keys():
         for Key in GPIASData['IndexTrace'][Freq].keys():
             # Average trials for traces
@@ -389,13 +386,13 @@ def Analysis(Data, DataInfo, Rate, AnalysisFolder, AnalysisKey,
         Keys = [['Gap', 'NoGap', 'GPIASIndex']]
 
         GPIASData['Index'][Freq] = IndexCalc(
-                                       GPIASData['IndexTrace'][Freq], Keys,
-                                       -int(TimeWindow[0]*Rate), SliceSize, False)
+            GPIASData['IndexTrace'][Freq], X, int(SliceSize*Rate),
+            Keys, BGNormalize
+        )
 
-    X = np.arange(int(TimeWindow[0]*Rate), int(TimeWindow[1]*Rate))*1000/Rate
 
-    if Save:
-        IO.Bin.Write({'GPIAS': GPIASData, 'X': X}, AnalysisFolder+'/'+AnalysisKey)
+    if len(Save):
+        IO.Bin.Write({'GPIAS': GPIASData, 'X': X}, Save)
 
     if Return: return(GPIASData, X)
     else: return(None)
