@@ -142,6 +142,9 @@ def GetTicks(Ax, Lim):
     return(Ticks)
 
 
+def InchToPoint(Size_in): return(Size_in*72)
+
+
 def InchToRealSize(Size_in, ScreenDPI=96, RealDPI=142):
     Size = Size_in*RealDPI/ScreenDPI
     return(Size)
@@ -165,13 +168,12 @@ def SameScale(Axes, Axis):
     return(None)
 
 
-def Set(Backend='TkCairo', Ax=None, Fig=None, AxArgs={}, FigTitle=None, Params=False,
+def Set(Ax=None, Fig=None, AxArgs={}, FigTitle=None, Params=False,
         HideControls=False, Tight=True):
 
 
     if Params:
         Params = {
-            'backend'             : Backend,
             'image.cmap'          : 'inferno',
             # 'savefig.dpi'         : 300,
             'savefig.format'      : 'svg',
@@ -208,8 +210,13 @@ def Set(Backend='TkCairo', Ax=None, Fig=None, AxArgs={}, FigTitle=None, Params=F
 
     if Ax:
         ## General
-        Ax.spines['bottom'].set_position(('outward', 2))
-        Ax.spines['left'].set_position(('outward', 2))
+        for ax in ['bottom', 'left']:
+            if ax+'pos' not in AxArgs: AxArgs[ax+'pos'] = 2
+            Ax.spines[ax].set_position(('outward', AxArgs[ax+'pos']))
+
+        # Ax.spines['bottom'].set_position(('outward', 2))
+        # Ax.spines['left'].set_position(('outward', 2))
+
         Ax.spines['right'].set_visible(False)
         Ax.spines['top'].set_visible(False)
         Ax.tick_params(top=False, right=False)
@@ -269,15 +276,10 @@ def Set(Backend='TkCairo', Ax=None, Fig=None, AxArgs={}, FigTitle=None, Params=F
     if Fig:
         if FigTitle: Fig.suptitle(FigTitle)
 
-        if HideControls:
-            if Backend[:2].lower() == 'tk': Fig.canvas.toolbar.pack_forget()
-            if Backend[:2].lower() == 'qt': Fig.canvas.toolbar.setVisible(False)
-
         if Tight:
             Fig.tight_layout()
             if FigTitle: Fig.subplots_adjust(top=0.85)
 
-        # for Obj in Fig.findobj(): Obj.set_clip_on(False)
         Fig.patch.set_visible(False)
 
     return(None)
@@ -696,6 +698,27 @@ def Comodulogram(Cmdlgrm, AmpFreq, PhaseFreq, CMap='inferno',
     return(Result)
 
 
+def MeanSEM(Data, X=[], LineArgs={}, FillArgs={},
+            Ax=None, AxArgs={}, File='MeanSEM', Ext=['pdf'], Save=False, Show=True):
+    AArg = AxArgs.copy()
+    Fig, Ax, ReturnAx = FigAx(Ax)
+
+    LineArgsDef = dict(color='k', lw=3, label='Mean')
+    FillArgsDef = dict(color='k', lw=0, alpha=0.3, label='SEM')
+    LA = {**LineArgsDef, **LineArgs}
+    FA = {**FillArgsDef, **FillArgs}
+
+    Mean = Data.mean(axis=1)
+    SEM = Data.std(axis=1) / (Data.shape[1]**0.5)
+
+    if not len(X): X = np.arange(len(Mean))
+    Ax.fill_between(X, Mean+SEM, Mean-SEM, **FA)
+    Ax.plot(X, Mean, **LA)
+
+    Result = SaveShow(ReturnAx, Fig, Ax, AArg, File, Ext, Save, Show)
+    return(Result)
+
+
 def Scatter3D(
         Data, ScatterArgs={}, Elevation=30, Azimuth=-130,
         ScaleBarArgs={},
