@@ -10,12 +10,8 @@
 import numpy as np
 from multiprocessing import Process
 
-from sciscripts.Analysis.Plot.Plot import Set
-
-Params = Set(Backend='Agg', Params=True)
-from matplotlib import rcParams; rcParams.update(Params)
-from matplotlib import pyplot as plt
-
+from sciscripts.Analysis.Plot import Plot
+plt = Plot.Return('plt')
 
 ## Level 0
 def UnitPerCh(ChDict, Ch, XValues, FigName, Ext):
