@@ -8,6 +8,7 @@
 """
 
 import numpy as np
+from itertools import combinations
 from rpy2 import robjects as RObj
 from rpy2.robjects import packages as RPkg
 
@@ -71,54 +72,35 @@ def RPCA(Matrix):
     return(PCA)
 
 
-def RAnOVaOneWay(Data, Factor):
+def RAnOVa(Data, Factors, Paired, Id=[]):
     RCheckPackage(['rstatix']); RPkg.importr('rstatix')
 
     Values = RObj.FloatVector(Data)
-    Factor = RObj.FactorVector(Factor)
+    FactorsV = [RObj.FactorVector(_) for _ in Factors]
+    Frame = {f'Factor{f+1}': F for f,F in enumerate(FactorsV)}
+    Frame['Values'] = Values
 
-    Frame = RObj.DataFrame({
-        'Values': Values,
-        'Factor': Factor,
-    })
-
-    RObj.globalenv["Frame"] = Frame
-    RObj.globalenv["Values"] = Values
-    RObj.globalenv["Factor"] = Factor
-    Model = RObj.r('''anova_test(Frame, Values ~ Factor)''')
-
-    return(Model)
-
-
-def RAnOVaTwoWay(Data, Factor1, Factor2, Id=[]):
-    RCheckPackage(['rstatix']); RPkg.importr('rstatix')
-
-    RepeatedMeasures = True if len(Id) else False
-
-    Values = RObj.FloatVector(Data)
-    Factors = [RObj.FactorVector(_) for _ in [Factor1, Factor2]]
-    Frame = {
-        'Values': Values,
-        'Factor1': Factors[0],
-        'Factor2': Factors[1],
-    }
-
-    if RepeatedMeasures:
+    if len(Id):
         Idv = RObj.IntVector(Id)
-        RObj.globalenv["Id"] = Idv
+        RObj.globalenv['Id'] = Idv
         Frame['Id'] = Idv
 
     Frame = RObj.DataFrame(Frame)
 
-    RObj.globalenv["Frame"] = Frame
-    RObj.globalenv["Values"] = Values
-    RObj.globalenv["Factor1"] = Factors[0]
-    RObj.globalenv["Factor2"] = Factors[1]
+    RObj.globalenv['Frame'] = Frame
+    RObj.globalenv['Values'] = Values
+    for F,Factor in enumerate(FactorsV): RObj.globalenv[f'Factor{F+1}'] = Factor
 
-    if RepeatedMeasures:
-        Model = RObj.r('''anova_test(Frame, dv=Values, wid=Id, within=c(Factor1,Factor2))''')
-    else:
-        Model = RObj.r('''anova_test(Frame, Values ~ Factor1*Factor2)''')
+    FactorsW = ','.join([f'Factor{_+1}' for _ in range(len(Factors)) if Paired[_]])
+    FactorsB = ','.join([f'Factor{_+1}' for _ in range(len(Factors)) if not Paired[_]])
+    Model = RObj.r(f'''anova_test(Frame, dv=Values, wid=Id, between=c({FactorsB}), within=c({FactorsW}))''')
+
+    # FactorsS = '*'.join([f'Factor{_+1}' for _ in range(len(Factors))])
+    # if RepeatedMeasures:
+        # Model = RObj.r(f'''anova_test(Frame, dv=Values, wid=Id, within=c({FactorsS.replace("*",",")}))''')
+        # Model = RObj.r(f'''anova_test(Values~{FactorsS} + Error(Id/({FactorsP})), data=Frame)''')
+    # else:
+        # Model = RObj.r(f'''anova_test(Frame, Values ~ {FactorsS})''')
 
     return(Model)
 
@@ -188,13 +170,33 @@ def RTTest(DataA, DataB, Paired=True, EqualVar=False, Alt='two.sided', Confidenc
 
 
 ## Level 2
-def AnOVa(Data, Factor1, Factor2=[], Id=[], Paired=[True, True]):
-    TwoWay = True if len(Factor2) else False
-    RepeatedMeasures = True if len(Id) else False
+def AnOVa(Data, Factors, Id=[], Paired=[]):
+    if not len(Paired): Paired = [False for _ in Factors]
+    PairedV = ['TRUE' if _ else 'FALSE' for _ in Paired]
+
+    # Combs = list(combinations(range(len(Factors)),len(Factors)-1))
+    # for F,Factor in enumerate(Factors):
+        # Others = [F not in _ for _ in Combs].index(True)
+        # Others = Combs[Others]
+
+        # OthersCond = []
+        # for O in Others:
+            # if not len(OthersCond): OthersCond =
+        # Paired = [
+            # O==ao for ao in np.unique(Others)]
+            # for O in Others
+        # ]
+
+    # # This works
+    # True in [a[((c==af1)*(d==af2)*(e==ai)).astype(bool)].shape[0]>1 for af1 in c for af2 in d for ai in e]
+    # # for data a; factors b,c and d; and id e
+    # # but how to dynamically iterate through different number of factors?
+
     ColsAnOVa = ['Effect', 'DFn', 'DFd', 'F', 'p', 'p<.05', 'ges', 'p.adj']
     ColsSph = ['Effect', 'W', 'p', 'p<.05']
     ColsSphCorr = ['Effect', 'GGe', 'DF[GG]', 'p[GG]', 'p[GG]<.05', 'HFe', 'DF[HF]', 'p[HF]']
     ColsPWC = [['Factor', '.y.', 'group1', 'group2', 'n1', 'n2']]*2
+
     ColsPWC = [
         Cols + ['statistic', 'df', 'p', 'p.adj', 'p.adj.signif']
         if Paired[C] else
@@ -202,43 +204,52 @@ def AnOVa(Data, Factor1, Factor2=[], Id=[], Paired=[True, True]):
         for C,Cols in enumerate(ColsPWC)
     ]
 
-    if TwoWay:
-        if RepeatedMeasures:
-            Model = RAnOVaTwoWay(Data, Factor1, Factor2, Id)
-        else:
-            Model = RAnOVaTwoWay(Data, Factor1, Factor2)
-    else:
-        Model = RAnOVaOneWay(Data, Factor1)
+    Model = RAnOVa(Data, Factors, Paired, Id)
 
-    if RepeatedMeasures:
-        FXs = {
-            'Factor1': RObj.r('''Frame %>% group_by(Factor2) %>% anova_test(dv=Values, wid=Id, within=Factor1) %>% get_anova_table() %>% adjust_pvalue(method="bonferroni")'''),
-            'Factor2': RObj.r('''Frame %>% group_by(Factor1) %>% anova_test(dv=Values, wid=Id, within=Factor2) %>% get_anova_table() %>% adjust_pvalue(method="bonferroni")''')
+    # if True in Paired:
+    FactorsW = [_ for _ in range(len(Factors)) if Paired[_]]
+    FPairs = tuple(combinations(range(len(Factors)), 2))
+
+    FXs = {}
+    for FPair in FPairs:
+        fw = [_ in FactorsW for _ in FPair]
+
+        fs = f'within=Factor{FPair[0]+1}' if fw[0] else f'between=Factor{FPair[0]+1}'
+        FXs[f'Factor{FPair[0]+1}'] = RObj.r(
+            f'''Frame %>% group_by(Factor{FPair[1]+1}) %>% anova_test(dv=Values, wid=Id, {fs}) %>% get_anova_table() %>% adjust_pvalue(method="bonferroni")'''
+        )
+
+        fs = f'within=Factor{FPair[1]+1}' if fw[0] else f'between=Factor{FPair[1]+1}'
+        FXs[f'Factor{FPair[1]+1}'] = RObj.r(
+            f'''Frame %>% group_by(Factor{FPair[0]+1}) %>% anova_test(dv=Values, wid=Id, {fs}) %>% get_anova_table() %>% adjust_pvalue(method="bonferroni")'''
+        )
+
+    PWC = {}
+    for FPair in FPairs:
+        PWC[f'Factor{FPair[0]+1}'] = RObj.r(
+            f'''Frame %>% group_by(Factor{FPair[1]+1}) %>% pairwise_t_test(Values~Factor{FPair[0]+1}, paired={PairedV[FPair[0]]}, p.adjust.method="bonferroni")'''
+        )
+        PWC[f'Factor{FPair[1]+1}'] = RObj.r(
+            f'''Frame %>% group_by(Factor{FPair[0]+1}) %>% pairwise_t_test(Values~Factor{FPair[1]+1}, paired={PairedV[FPair[1]]}, p.adjust.method="bonferroni")'''
+        )
+
+    if Model.rclass[1] == 'list':
+        Results = {
+            'ANOVA': RModelToDict(Model[0]),
+            'MauchlySphericity': RModelToDict(Model[1]),
+            'SphericityCorrection': RModelToDict(Model[2]),
+            'FXFactors': {F: RModelToDict(Fac) for F,Fac in FXs.items()},
+            'PWCs': {F: RModelToDict(Fac) for F,Fac in PWC.items()}
+        }
+    else:
+        Results = {
+            'ANOVA': RModelToDict(Model),
+            'FXFactors': {F: RModelToDict(Fac) for F,Fac in FXs.items()},
+            'PWCs': {F: RModelToDict(Fac) for F,Fac in PWC.items()}
         }
 
-        Paired = ['TRUE' if _ else 'FALSE' for _ in Paired]
-        PWC = {
-            'Factor1': RObj.r('''Frame %>% group_by(Factor2) %>% pairwise_t_test(Values~Factor1, paired='''+Paired[0]+r''', p.adjust.method="bonferroni")'''),
-            'Factor2': RObj.r('''Frame %>% group_by(Factor1) %>% pairwise_t_test(Values~Factor2, paired='''+Paired[1]+r''', p.adjust.method="bonferroni")''')
-        }
-
-        if Model.rclass[1] == 'list':
-            Results = {
-                'ANOVA': RModelToDict(Model[0]),
-                'MauchlySphericity': RModelToDict(Model[1]),
-                'SphericityCorrection': RModelToDict(Model[2]),
-                'FXFactors': {F: RModelToDict(Fac) for F,Fac in FXs.items()},
-                'PWCs': {F: RModelToDict(Fac) for F,Fac in PWC.items()}
-            }
-        else:
-            Results = {
-                'ANOVA': RModelToDict(Model),
-                'FXFactors': {F: RModelToDict(Fac) for F,Fac in FXs.items()},
-                'PWCs': {F: RModelToDict(Fac) for F,Fac in PWC.items()}
-            }
-
-    else:
-        Results = {'ANOVA': RModelToDict(Model)}
+    # else:
+        # Results = {'ANOVA': RModelToDict(Model)}
 
     return(Results)
 
