@@ -16,7 +16,7 @@ def GetSxx(Data, Rate, SensorCh, PeakDist, Lowpass=5, FilterOrder=2, Theta=[7, 1
     SensorData = Analysis.FilterSignal(SensorData, Rate, [Lowpass], FilterOrder,
                               'butter', 'lowpass')
 
-    Peaks = Analysis.QuantifyTTLsPerRec(True, SensorData)
+    Peaks = Analysis.QuantifyTTLs(SensorData)
 
     V = np.zeros(len(SensorData))
     for P in range(1, len(Peaks)):
