@@ -229,7 +229,7 @@ def UnitRecLoad(Folder):
 
 
 ## Level 1
-def GetAllUnits(ClustersPath, TimeWindow, ISISize=0.01, TTLCh=None, BinSize=None, AnalogTTLs=True, Save=True, Return=True, **Kws):
+def GetAllUnits(ClustersPath, TimeWindow, ISISize=0.01, TTLCh=None, BinSize=None, Save=True, Return=True, **Kws):
     AnalysisPath = '_'.join(ClustersPath.split('_')[:-1])+'_AllUnits'
     SpkClusters = IO.Bin.Read(ClustersPath+'/SpkClusters.dat')[0]
     SpkRecs = IO.Bin.Read(ClustersPath+'/SpkRecs.dat')[0]
@@ -325,7 +325,7 @@ def GetAllUnits(ClustersPath, TimeWindow, ISISize=0.01, TTLCh=None, BinSize=None
                     TTLs = TTLs.reshape((TTLs.shape[0]//ChNoTotal, ChNoTotal))
 
                 print('Quantifying... ')
-                TTLs = Analysis.QuantifyTTLsPerRec(AnalogTTLs, TTLs[:,TTLCh-1], 1)
+                TTLs = Analysis.QuantifyTTLs(TTLs[:,TTLCh-1], 1)
                 if type(TTLs) == tuple: TTLs = TTLs[0]
                 if type(TTLs) != np.ndarray: TTLs = np.array(TTLs)
                 print('Saving TTLs to', TTLFile, '...')
