@@ -150,9 +150,9 @@ def Run(AnimalName, StimType, BGIntensity, PulseIntensity,
         NoiseFrequency, SoundBGDur, SoundGapDur,
         SoundBGPrePulseDur, SoundLoudPulseDur,
         SoundBGAfterPulseDur, SoundBetweenStimDur, NoOfTrials,
-        System, Setup, StimCh, TTLCh, RecCh, AnalogTTLs=True,
+        System, Setup, StimCh, TTLCh, RecCh,
         Rate=192000, BlockSize=384, Channels=2, BaudRate=115200, TTLAmpF = 1,
-        PrePost=0, GapIntensity=0, **Kws):
+        PrePost=0, GapIntensity=[0], **Kws):
 
     SoundBGAmpF = DAqs.dBToAmpF(BGIntensity, System, Setup)
     SoundPulseAmpF = DAqs.dBToAmpF(PulseIntensity, System, Setup)
@@ -167,11 +167,7 @@ def Run(AnimalName, StimType, BGIntensity, PulseIntensity,
     Sound = GPIASSound(Map=Map, **DataInfo['Audio'])
     Stim = SoundCard.AudioSet(Rate, BlockSize, Channels, ReturnStream='Out')
     ArduinoObj = Arduino.CreateObj(BaudRate)
-    if not ArduinoObj:
-        print('No Arduino detected!!!')
-        print('NO DIGITAL TTLs WILL BE DELIVERED!!!')
-        print('YOU HAVE BEEN WARNED!!!')
-        print('Analog TTLs will still work.')
+    if not ArduinoObj: print(Arduino.NotFoundWarning())
 
     try:
         Play(Sound, Stim, ArduinoObj, DataInfo=DataInfo, **DataInfo['Audio'])
