@@ -21,19 +21,6 @@ from sciscripts.IO import Arduino, DAqs, SigGen, Txt
 from sciscripts.IO.SoundCard import AudioSet
 
 
-def CalibrationOverrideWarning():
-    Msg = f'=========================== WARNING =============================\n'
-    Msg += 'You provided specific voltages to drive the speaker. That means\n'
-    Msg += 'that the sound intensities were NOT calibrated by SciScripts. Thus,\n'
-    Msg += 'the stimulus will NOT be normalized according to the sound card\n'
-    Msg += 'amplification neither corrected for the sound card filter settings.\n\n'
-    Msg += 'It is HIGHLY UNLIKELY that the intensities requested at the\n'
-    Msg += 'Intensities variable will be the real intensity played.\n\n'
-    Msg += 'You should calibrate your setup first, or ensure that the correct\n'
-    Msg += 'intensities are being played externally.\n'
-    Msg += '=================================================================\n'
-    return(Msg)
-
 def Prepare(AnimalName, StimType, System, Setup, StimCh=None, TTLCh=None,
             RecCh=None, SoundType=None,
             Intensities=None, NoiseFrequency=None, SoundPulseNo=None,
@@ -42,7 +29,7 @@ def Prepare(AnimalName, StimType, System, Setup, StimCh=None, TTLCh=None,
             LaserStimBlockNo=None, LaserPulseNo=None, LaserPauseBeforePulseDur=None,
             LaserPulseDur=None, LaserPauseAfterPulseDur=None,
             LaserPauseBetweenStimBlocksDur=None, LaserType=None, LaserDur=None, LaserFreq=None,
-            AnalogTTLs=True, Rate=None, BlockSize=384, Channels=2,
+            Rate=None, BlockSize=384, Channels=2,
             BaudRate=115200, TTLAmpF=1, Probe=None, Adaptor=None, Remapped=False, ChSpacing=None, TTLs=True, StimulationDelay=0, **Kws):
 
     SoundReq = [
@@ -59,7 +46,7 @@ def Prepare(AnimalName, StimType, System, Setup, StimCh=None, TTLCh=None,
     if 'Sound' in StimType or 'SoundLaser' in StimType:
         if 'SoundAmpF' in Kws.keys():
             SoundAmpF = Kws['SoundAmpF']
-            print(CalibrationOverrideWarning())
+            print(DAqs.CalibrationOverrideWarning())
         else:
             SoundAmpF = DAqs.dBToAmpF(Intensities, System, Setup)
 
@@ -76,11 +63,7 @@ def Prepare(AnimalName, StimType, System, Setup, StimCh=None, TTLCh=None,
     Stimulation = {}
     Stimulation['Stim'] = AudioSet(Rate, BlockSize, Channels, 'Out')
     Stimulation['ArduinoObj'] = Arduino.CreateObj(BaudRate)
-    if not Stimulation['ArduinoObj']:
-        print('No Arduino detected!!!')
-        print('NO DIGITAL TTLs WILL BE DELIVERED!!!')
-        print('YOU HAVE BEEN WARNED!!!')
-        print('Analog TTLs will still work.')
+    if not Stimulation['ArduinoObj']: print(Arduino.NotFoundWarning())
 
     if Rate is None:
         Rate = int(Stimulation['Stim'].samplerate)
