@@ -41,6 +41,18 @@ def GetSerialData(FramesPerBuf, ArduinoObj):
     return(Data)
 
 
+def NotFoundWarning():
+    Msg = f'=============== WARNING =================\n'
+    Msg += 'No Arduino detected!!!\n'
+    Msg += 'NO DIGITAL TTLs WILL BE DELIVERED!!!\n'
+    Msg += 'YOU HAVE BEEN WARNED!!!\n'
+    Msg += '\n'
+    Msg += 'Analog TTLs will still work.\n'
+    Msg += '=========================================\n'
+    return(Msg)
+
+
+
 def Reset(Obj):
     Obj.setDTR(False)
     Obj.flushInput()
