@@ -17,7 +17,7 @@ from sciscripts.IO import Asdf, Bin, Hdf5, Intan, OpenEphys, Txt
 print('[IO.IO] Done.')
 
 
-def DataLoader(Folder, Unit='uV', ChannelMap=[], AnalogTTLs=True, ImpedanceFile='', Processor=None, Experiment=None, Recording=None):
+def DataLoader(Folder, Unit='uV', ChannelMap=[], ImpedanceFile='', Processor=None, Experiment=None, Recording=None):
     FilesExt = [F.split('.')[-1] for F in glob(Folder+'/*.*')]
 
     if 'kwd' in FilesExt: Data, Rate = OpenEphys.OpenEphys.KwikLoad(Folder, Unit, ChannelMap, ImpedanceFile, Processor, Experiment, Recording)
@@ -30,18 +30,7 @@ def DataLoader(Folder, Unit='uV', ChannelMap=[], AnalogTTLs=True, ImpedanceFile=
     elif Folder[-5:] == '.asdf': Data = Asdf.Read(Folder); Rate = None
     else: print('Data format not supported.'); return(None)
 
-    if not AnalogTTLs:
-        if 'kwd' in FilesExt:
-            Kwds = glob(Folder+'/*.events')
-            if len(Kwds) > 1: print('Multiple sessions not supported yet.'); return(None)
-
-            EventsDict = 'ToBeContinued'
-        elif 'events' in FilesExt:
-            EventsDict = OpenEphys.OpenEphys.EventsLoad(Folder)
-
-        return(Data, Rate, EventsDict)
-    else:
-        return(Data, Rate)
+    return(Data, Rate)
 
 
 def DataWriter(Data, Path, Ext):
