@@ -120,10 +120,8 @@ def PrmWrite(File, experiment_name, prb_file, raw_data_files, sample_rate,
     return(None)
 
 
-def Run(PrmFile, Path, Overwrite=False):
+def Run(PrmFile, Path, Overwrite=False, Klusta=os.environ['HOME']+'/.local/bin/klusta'):
     Here = os.getcwd(); os.chdir(Path)
-    # Klusta = os.environ['HOME']+'/Software/Miniconda3/envs/klusta/bin/klusta'
-    Klusta = os.environ['HOME']+'/.local/bin/klusta'
     Cmd = [Klusta, PrmFile]
     if Overwrite: Cmd.append('--overwrite')
 
@@ -139,9 +137,8 @@ def Run(PrmFile, Path, Overwrite=False):
     return(None)
 
 
-def Phy_Run(KwikFile, Path):
+def Phy_Run(KwikFile, Path, Phy=s.environ['HOME']+'/.local/bin/phy'):
     Here = os.getcwd(); os.chdir(Path)
-    Phy = os.environ['HOME']+'/Software/Miniconda3/envs/klusta/bin/phy'
     Cmd = [Phy, 'kwik-gui', KwikFile, '--debug']
 
     print('Entering in directory', Path, '...')
