@@ -7,7 +7,7 @@
 @homepage: https://gitlab.com/Malfatti/SciScripts
 """
 
-# from sciscripts.IO.OpenEphys import Binary
-# from sciscripts.IO.OpenEphys import OpenEphysFormat
-# from sciscripts.IO.OpenEphys import OpenEphys
-# from sciscripts.IO.OpenEphys import SettingsXML
+from sciscripts.IO.OpenEphys import Binary
+from sciscripts.IO.OpenEphys import OpenEphysFormat
+from sciscripts.IO.OpenEphys import OpenEphys
+from sciscripts.IO.OpenEphys import SettingsXML
