@@ -16,12 +16,7 @@ print('[IO.SigGen] Done.')
 
 SoundTTLVal = 0.1; LaserTTLVal = 1
 
-def FreqStr2Int(Freq):
-    Freq = Freq.split('-')
-    IntFreq = sum([float(_) for _ in Freq])/len(Freq)
-    return(IntFreq)
-
-
+## Level 0
 def ApplyRamp(Signal, Rate, RampRiseDur, RampFallDur, Mode='linear'):
     Ramp = np.ones((Rate*len(Signal)), dtype=np.float32)
     Ramp[:Rate*RampRiseDur] = np.linspace(0, 1, Rate*RampRiseDur)
@@ -31,50 +26,6 @@ def ApplyRamp(Signal, Rate, RampRiseDur, RampFallDur, Mode='linear'):
     return(Signal)
 
 
-## Level 0
-def ApplySoundAmpF(SoundPulseFiltered, Rate, SoundAmpF, NoiseFrequency,
-                   SoundPauseBeforePulseDur=0, SoundPauseAfterPulseDur=0):
-    """Returns an array of dimensions [Data, AmpF, Freq]."""
-
-    print('Applying amplification factors...')
-    # Preallocating memory
-    TotalDur = round(Rate * (SoundPauseBeforePulseDur+SoundPauseAfterPulseDur))+SoundPulseFiltered.shape[0]
-    if type(NoiseFrequency[0]) == list:
-        Freqs = ['-'.join([str(_) for _ in F]) for F in NoiseFrequency]
-    else:
-        Freqs = [str(F) for F in NoiseFrequency]
-
-    Start = int(round(SoundPauseBeforePulseDur*Rate))
-    End = -int(round(SoundPauseAfterPulseDur*Rate))
-    if End == 0: End = TotalDur
-
-    SoundUnit = np.zeros((TotalDur, len(SoundAmpF[list(SoundAmpF)[0]]), len(Freqs)), dtype='float32')
-
-    for F,Freq in enumerate(Freqs):
-        if Freq not in SoundAmpF:
-            # FAmpF = SoundAmpF[list(SoundAmpF)[0]]
-            # Estimate closest calibrated frequency
-            IntFreq = [[F,F] for F in SoundAmpF.keys()]
-            IntFreq = list(map(list, zip(*IntFreq)))
-
-            IntFreq[1] = [FreqStr2Int(Freq) for Freq in IntFreq[1]]
-
-            RealFKey = FreqStr2Int(FKey)
-            RealFKey = min(IntFreq[1], key=lambda x:abs(x-RealFKey))
-            RealFKey = IntFreq[0][IntFreq[1].index(RealFKey)]
-
-            FAmpF = SoundAmpF[RealFKey]
-            # print('FKey:', RealFKey)
-        else:
-            FAmpF = SoundAmpF[Freq]
-            # print('FKey:', FKey)
-
-        for A,AmpF in enumerate(FAmpF):
-            SoundUnit[Start:End,A,F] = SoundPulseFiltered[:,F] * AmpF
-
-    return(SoundUnit)
-
-
 def BandpassFilterSound(SoundPulse, Rate, NoiseFrequency):
     """Returns an array of dimensions [Data,Freq]."""
 
@@ -99,6 +50,12 @@ def BandpassFilterSound(SoundPulse, Rate, NoiseFrequency):
     return(SoundPulseFiltered)
 
 
+def FreqRangeStrToInt(Freq):
+    Freq = Freq.split('-')
+    IntFreq = sum([float(_) for _ in Freq])/len(Freq)
+    return(IntFreq)
+
+
 def Noise(Rate, SoundPulseDur):
     print('Generating noise...')
     Noise = np.random.uniform(-1, 1, size=round(Rate*SoundPulseDur))
@@ -136,16 +93,6 @@ def SineWave(Rate, Freq, AmpF, Time):
     return(Pulse)
 
 
-def TTLSqPulse(Rate, PulseDur, TTLAmpF, TTLVal, PauseBeforePulseDur=0,
-           PauseAfterPulseDur=0):
-    Pulse = np.concatenate([
-                np.zeros(PauseBeforePulseDur*Rate, dtype=np.float32),
-                np.ones(PulseDur*Rate, dtype=np.float32) * TTLAmpF * TTLVal,
-                np.zeros(PauseAfterPulseDur*Rate, dtype=np.float32)])
-
-    return(Pulse)
-
-
 def SqWave(Rate, PulseDur, TTLAmpF, TTLVal, PauseBeforePulseDur=0,
            PauseAfterPulseDur=0):
 
@@ -185,6 +132,16 @@ def SqWave(Rate, PulseDur, TTLAmpF, TTLVal, PauseBeforePulseDur=0,
     return(TTLUnit)
 
 
+def TTLSqPulse(Rate, PulseDur, TTLAmpF, TTLVal, PauseBeforePulseDur=0,
+           PauseAfterPulseDur=0):
+    Pulse = np.concatenate([
+                np.zeros(PauseBeforePulseDur*Rate, dtype=np.float32),
+                np.ones(PulseDur*Rate, dtype=np.float32) * TTLAmpF * TTLVal,
+                np.zeros(PauseAfterPulseDur*Rate, dtype=np.float32)])
+
+    return(Pulse)
+
+
 def TTLSqWave(Rate, PulseDur, TTLAmpF, TTLVal, PauseBeforePulseDur=0,
            PauseAfterPulseDur=0):
 
@@ -214,7 +171,59 @@ def TTLSqWave(Rate, PulseDur, TTLAmpF, TTLVal, PauseBeforePulseDur=0,
     return(TTLUnit)
 
 
+def TTLVector(TTLs, TTLLen, FullLen):
+    TTLVec = np.zeros([FullLen, 1])
+
+    for TTL in TTLs:
+        TTLVec[TTL:TTL+TTLLen] = 1
+
+    return(TTLVec)
+
+
 ## Level 1
+def ApplySoundAmpF(SoundPulseFiltered, Rate, SoundAmpF, NoiseFrequency,
+                   SoundPauseBeforePulseDur=0, SoundPauseAfterPulseDur=0):
+    """Returns an array of dimensions [Data, AmpF, Freq]."""
+
+    print('Applying amplification factors...')
+    # Preallocating memory
+    TotalDur = round(Rate * (SoundPauseBeforePulseDur+SoundPauseAfterPulseDur))+SoundPulseFiltered.shape[0]
+    if type(NoiseFrequency[0]) == list:
+        Freqs = ['-'.join([str(_) for _ in F]) for F in NoiseFrequency]
+    else:
+        Freqs = [str(F) for F in NoiseFrequency]
+
+    Start = int(round(SoundPauseBeforePulseDur*Rate))
+    End = -int(round(SoundPauseAfterPulseDur*Rate))
+    if End == 0: End = TotalDur
+
+    SoundUnit = np.zeros((TotalDur, len(SoundAmpF[list(SoundAmpF)[0]]), len(Freqs)), dtype='float32')
+
+    for F,Freq in enumerate(Freqs):
+        if Freq not in SoundAmpF:
+            # FAmpF = SoundAmpF[list(SoundAmpF)[0]]
+            # Estimate closest calibrated frequency
+            IntFreq = [[F,F] for F in SoundAmpF.keys()]
+            IntFreq = list(map(list, zip(*IntFreq)))
+
+            IntFreq[1] = [FreqRangeStrToInt(Freq) for Freq in IntFreq[1]]
+
+            RealFKey = FreqRangeStrToInt(FKey)
+            RealFKey = min(IntFreq[1], key=lambda x:abs(x-RealFKey))
+            RealFKey = IntFreq[0][IntFreq[1].index(RealFKey)]
+
+            FAmpF = SoundAmpF[RealFKey]
+            # print('FKey:', RealFKey)
+        else:
+            FAmpF = SoundAmpF[Freq]
+            # print('FKey:', FKey)
+
+        for A,AmpF in enumerate(FAmpF):
+            SoundUnit[Start:End,A,F] = SoundPulseFiltered[:,F] * AmpF
+
+    return(SoundUnit)
+
+
 def LaserStim(Rate, LaserPulseDur, LaserDur, LaserFreq, System, TTLAmpF=1, LaserPauseBeforePulseDur=0, LaserPauseAfterPulseDur=0, Ch=1, LaserType='Sq', **Kws):
     """
     if LaserType == 'Sq':
@@ -251,6 +260,7 @@ def LaserStim(Rate, LaserPulseDur, LaserDur, LaserFreq, System, TTLAmpF=1, Laser
     return(Laser)
 
 
+## Level 2
 def SoundStim(Rate, SoundPulseDur, SoundAmpF, NoiseFrequency,
               System, TTLAmpF=1, SoundPauseBeforePulseDur=0, SoundPauseAfterPulseDur=0, TTLs=True,
               Map=[1,2], SoundType='Noise', **Kws):
@@ -311,7 +321,7 @@ def SoundStim(Rate, SoundPulseDur, SoundAmpF, NoiseFrequency,
     return(Sound)
 
 
-## Level 2
+## Level 3
 def SoundLaserStim(Rate, SoundPulseDur, SoundAmpF, NoiseFrequency, System, LaserPulseDur, LaserType, LaserDur, LaserFreq, TTLAmpF=1, SoundPauseBeforePulseDur=0, SoundPauseAfterPulseDur=0, TTLs=True, Map=[1,2], SoundType='Noise', LaserPauseBeforePulseDur=0, LaserPauseAfterPulseDur=0, **Kws):
     """ Generate sound pulses in one channel and a mix of square waves that
         works as TTLs for both sound and laser in the other channel.
