@@ -8,7 +8,7 @@
 """
 
 from sciscripts.IO.IO import RunProcess
-from scipy.io import loadmat
+from sciscripts.IO.Mat import Read
 
 
 def LoadClusters(FileList):
@@ -16,7 +16,7 @@ def LoadClusters(FileList):
     for File in FileList:
         Ch = File[-8:-4]
 
-        ClusterFile = loadmat(File)
+        ClusterFile = Read(File)
         Clusters[Ch] = {}
         Clusters[Ch]['Id'] = ClusterFile['cluster_class'][:, 0]
         Clusters[Ch]['Timestamps'] = ClusterFile['cluster_class'][:, 1]
@@ -28,7 +28,6 @@ def LoadClusters(FileList):
 def Run(Rate, Path):
     print('Clustering spikes...')
 
-#    MLab = '/home/cerebro/Software/Programs/MatLabR2014a/bin/matlab'
     MLab = '/home/malfatti/Software/Programs/MatLabR2015a/bin/matlab'
     CmdCd = 'cd ' + Path + '; '
     CmdCluster = 'try, par.sr=' + str(int(Rate)) + '; ' + \
